# Generated by Django 2.1.3 on 2019-02-07 22:17

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='DatabasePurger',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('enabled', models.BooleanField(default=True)),
                ('delete_by_age', models.BooleanField(default=True, help_text='Delete if entry is older than specified age')),
                ('delete_by_quantity', models.BooleanField(default=False, help_text='Delete all except the youngest `max_records` entries')),
                ('datetime_field', models.CharField(default='created', help_text='Field used to determine the age of a record', max_length=255)),
                ('age_in_days', models.PositiveIntegerField(default=30, help_text='If `delete_by_age` is selected, delete records older than this age')),
                ('max_records', models.PositiveIntegerField(default=1000, help_text='Number of records to keep if `delete_by_quantity` is selected')),
                ('tables', models.ManyToManyField(to='contenttypes.ContentType')),
            ],
            options={
                'verbose_name': 'Database Purger',
            },
        ),
    ]
